@@ -17,6 +17,14 @@ test_that("closed curves",{
   expect_warning(plot(aligned_curves_closed), regexp = NA)
 })
 
+test_that("1d function",{
+  t_grid = 0:20/20
+  data_curve1 <- data.frame(t = t_grid, x = sin(6*t_grid))
+  data_curve2 <- data.frame(t = t_grid, x = cos(3*t_grid - 1))
+  expect_warning(aligned_curves <- align_curves(data_curve1, data_curve2))
+  expect_warning(plot(aligned_curves), regexp = NA)
+})
+
 test_that("get_warping",{
   data_curve1 <- data.frame(x1 = c(1, 0.5, -1, -1), x2 = c(1, -0.5, -1, 1))
   data_curve2 <- data.frame(x1 = c(0.1,0.7)*sin(3:8), x2 = cos(3:8))
@@ -24,7 +32,7 @@ test_that("get_warping",{
   expect_true(all(aligned_curves$data_curve2_aligned$t_optim %in% get_warping(aligned_curves)$t))
 })
 
-test_that("only for 2d curves",{
+test_that("only for 1d or 2d curves",{
   data_curve1 <- data.frame(x1 = c(1, 0.5, -1, -1), x2 = c(1, -0.5, -1, 1), x3 = c(1, -0.5, -1, 1))
   data_curve2 <- data.frame(x1 = c(0.1,0.7)*sin(1:6), x2 = cos(1:6), x3 = cos(1:6))
   aligned_curves <- align_curves(data_curve1, data_curve2)
